import {
  userInfoRespSchema,
  userInfoRespSchemaNullable,
  type SucceedUserInfoResp,
  type SucceedUserInfoRespNullable,
} from '@/schemas/response';
import { useUserStore } from '@/stores/user';
import axios, { type AxiosError } from 'axios';
import { ElMessage } from 'element-plus';
import { errorMessage, withCatchRequestError } from '../utils/api';
import { parseRawResp } from '../schemas';

const axiosInstance = axios.create({
  baseURL: import.meta.env.VITE_REQUEST_BASE_URL,
});
// 自动添加token到请求中.
axiosInstance.interceptors.request.use((config) => {
  const userStore = useUserStore();
  config.headers.setAuthorization(userStore.token, false);
  return config;
});
// 自动获取响应中的token.
axiosInstance.interceptors.response.use((response) => {
  const userStore = useUserStore();
  const authorization = response.headers['set-authorization'] as string | undefined;
  if (authorization) {
    console.log(123);
    userStore.token = authorization;
  }
  return response;
});
export default axiosInstance;
export type RawResp = Record<string, unknown>;
export async function getUserInfo(): Promise<SucceedUserInfoResp>;
export async function getUserInfo(userID: number): Promise<SucceedUserInfoRespNullable>;
export async function getUserInfo(userID?: number) {
  let url = '/api/user/info';
  if (userID !== undefined) {
    url += `/${userID}`;
  }
  const resp = parseRawResp(
    userID !== undefined ? userInfoRespSchemaNullable : userInfoRespSchema,
    await withCatchRequestError(axiosInstance.get<RawResp>(url).then((r) => r.data)),
  );
  return resp;
}
