import type { RawResp } from '@/api';
import { ElMessage } from 'element-plus';
import type { z } from 'zod';
import type { AnyRespSchema, SucceedRespOf } from './response';

export function parseRawResp<T extends AnyRespSchema>(
  schema: T,
  raw: RawResp | undefined,
): SucceedRespOf<z.infer<T>> | undefined {
  if (!raw) return;
  const resp = schema.parse(raw);
  if (resp.type === 'error') {
    ElMessage.error([resp.code, resp.msg].join(':'));
    return;
  }
  return resp as any;
}
